@@ -55,12 +55,16 @@ PcaClassic.default <- function(x, k=ncol(x), kmax=ncol(x),
     n <- nrow(data)
     p <- ncol(data)
 
-##    Xsvd <- kernelEVD(data, scale=scale, signflip=signflip)
-    Xsvd <- classPC(data, scale=scale, signflip=signflip)
+    Xsvd <- .classPC(data, scale=scale, signflip=signflip, scores=TRUE)
     if(Xsvd$rank == 0) {
         stop("All data points collapse!")
     }
 
+    myrank <- Xsvd$rank
+
+    if(is.logical(scale) && !scale)         # no scaling, the defult
+        Xsvd$scale <- vector('numeric', p) + 1
+
     if(trace)
     {
         cat("\nDimension of the input matrix x:\n", dim(x))
@@ -113,14 +117,10 @@ PcaClassic.default <- function(x, k=ncol(x), kmax=ncol(x),
     loadings    <- Xsvd$loadings[, 1:k, drop=FALSE]
     eigenvalues <- as.vector(Xsvd$eigenvalues[1:k])
     center      <- as.vector(Xsvd$center)
-
-##    VT::30.10.2014 - kernelEVD is simplified and moved to robustbase:
-##      no more returns scores
-##    scores      <- Xsvd$scores[, 1:k, drop=FALSE]
-    scores <- scale(data, Xsvd$center, Xsvd$scale) %*% Xsvd$loadings
-    scores <- scores[, 1:k, drop=FALSE]
-
+    scores      <- Xsvd$scores[, 1:k, drop=FALSE]
     scale       <- Xsvd$scale
+    eig0 <- as.vector(Xsvd$eigenvalues)
+    totvar0 <- sum(eig0)
 
     if(is.list(dimnames(data)) && !is.null(dimnames(data)[[1]]))
     {
@@ -134,13 +134,16 @@ PcaClassic.default <- function(x, k=ncol(x), kmax=ncol(x),
     ## fix up call to refer to the generic, but leave arg name as 'formula'
     cl[[1]] <- as.name("PcaClassic")
     res <- new("PcaClassic", call=cl,
+                            rank=myrank,
                             loadings=loadings,
                             eigenvalues=eigenvalues,
                             center=center,
                             scale=scale,
                             scores=scores,
                             k=k,
-                            n.obs=n)
+                            n.obs=n,
+                            eig0=eig0,
+                            totvar0=totvar0)
 
     ## Compute distances and flags
     res <- pca.distances(res, data, Xsvd$rank, crit.pca.distances)
